@@ -39,7 +39,6 @@ Icon::Icon(QQuickItem *parent)
 
     connect(this, &QQuickItem::smoothChanged, this, &QQuickItem::polish);
     connect(this, &QQuickItem::enabledChanged, this, [this]() {
-        m_allowNextAnimation = true;
         polish();
     });
 }
@@ -109,9 +108,6 @@ void Icon::setActive(const bool active)
         return;
     }
     m_active = active;
-    if (isComponentComplete()) {
-        m_allowNextAnimation = true;
-    }
     polish();
     Q_EMIT activeChanged();
 }
@@ -409,14 +405,13 @@ void Icon::updatePolish()
     }
 
     // don't animate initial setting
-    bool animated = (m_animated || m_allowNextAnimation) && !m_oldIcon.isNull() && !m_sizeChanged && !m_blockNextAnimation;
+    bool animated = m_animated && !m_oldIcon.isNull() && !m_sizeChanged && !m_blockNextAnimation;
 
     if (animated && m_animation) {
         m_animValue = 0.0;
         m_animation->setStartValue((qreal)0);
         m_animation->setEndValue((qreal)1);
         m_animation->start();
-        m_allowNextAnimation = false;
     } else {
         if (m_animation) {
             m_animation->stop();
@@ -535,11 +530,7 @@ QImage Icon::findIcon(const QSize &size)
             iconSource = QUrl(iconSource).path();
         }
 
-        QIcon icon;
-
-        const QColor tintColor =
-            !m_color.isValid() || m_color == Qt::transparent ? (m_selected ? m_theme->highlightedTextColor() : m_theme->textColor()) : m_color;
-        icon = m_theme->iconFromTheme(iconSource, tintColor);
+        const QIcon icon = loadFromTheme(iconSource);
 
         if (!icon.isNull()) {
             img = iconPixmap(icon);
@@ -631,7 +622,25 @@ QSize Icon::iconSizeHint() const
 QImage Icon::iconPixmap(const QIcon &icon) const
 {
     const QSize actualSize = icon.actualSize(iconSizeHint());
-    return icon.pixmap(actualSize, m_devicePixelRatio, iconMode(), QIcon::On).toImage();
+    QIcon sourceIcon = icon;
+
+    // if we have a non-default theme we need to load the icon with
+    // the right colors
+    const QQmlEngine *engine = qmlEngine(this);
+    if (engine && !engine->property("_kirigamiTheme").toString().isEmpty()) {
+        const QString iconName = icon.name();
+        if (!iconName.isEmpty() && QIcon::hasThemeIcon(iconName)) {
+            sourceIcon = loadFromTheme(iconName);
+        }
+    }
+
+    return sourceIcon.pixmap(actualSize, m_devicePixelRatio, iconMode(), QIcon::On).toImage();
+}
+
+QIcon Icon::loadFromTheme(const QString &iconName) const
+{
+    const QColor tintColor = !m_color.isValid() || m_color == Qt::transparent ? (m_selected ? m_theme->highlightedTextColor() : m_theme->textColor()) : m_color;
+    return m_theme->iconFromTheme(iconName, tintColor);
 }
 
 void Icon::updatePaintedGeometry()
